@@ -27,19 +27,20 @@
  * 02110-1301 USA
 	
 */
-
+/*******************************************************************************/
 #include "weather-event.h"
-
+/*******************************************************************************/
 static GSList *event_time_list = NULL;
-
+/*******************************************************************************/
 gboolean timer_handler(gpointer data){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
     time_t current_time;
+    int check;
 #ifdef PC_EMULATOR
     char   *temp_string;
+    fprintf(stderr, "Begin %s(): \n", __PRETTY_FUNCTION__);
 #endif
-
     if(not_event == TRUE || !event_time_list)
 	return TRUE;
 
@@ -50,7 +51,7 @@ gboolean timer_handler(gpointer data){
     temp_string = ctime(&current_time);
     fprintf(stderr,"\nCurrent Time: %s\n",  temp_string);
 /*    g_free(temp_string);*/
-    print_list();
+    print_list(NULL, 0);
 #endif	
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
@@ -66,6 +67,9 @@ gboolean timer_handler(gpointer data){
 		    g_free(evt);
                     event_time_list = g_slist_remove(event_time_list, event_time_list->data);
 		    weather_initialize_dbus();
+		    /* It is switch off the timer */	
+		    check = g_source_remove(app->timer);
+		    timer (60000);  /* One per minute */
 		break;    
 		default:
 		case AUTOUPDATE:
@@ -82,7 +86,6 @@ gboolean timer_handler(gpointer data){
 		    update_weather();
                     /* add periodic update */
                     add_periodic_event(current_time);
-		    
     		break;		    
 	    }
 	    break;
@@ -91,32 +94,40 @@ gboolean timer_handler(gpointer data){
     }
     return TRUE;    
 }
-
-#ifdef PC_EMULATOR
+/*******************************************************************************/
+//#ifdef PC_EMULATOR
 /*For debug */
-void print_list(void){
+void print_list(char *buff, size_t buff_size){
     static GSList *list_time_event_temp = NULL;
     struct event_time *evt;
+    char	tmp[3072];
 
+    memset(tmp, 0, sizeof(tmp));
     if(!event_time_list)
 	return;
     list_time_event_temp = event_time_list;
-    fprintf(stderr, "\n");
+    sprintf(tmp, "Length %i\n",g_slist_length (list_time_event_temp)  );    
     while(list_time_event_temp){
 	evt = list_time_event_temp->data;
-	fprintf(stderr,"Event %i Time: %s", evt->type_event, ctime(&evt->time));
+	snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1,
+		    "Event %i Time: %s\n", 
+		    evt->type_event, ctime(&evt->time));
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
-    fprintf(stderr, "\n");
+    snprintf(tmp + strlen(tmp), sizeof(tmp) - strlen(tmp) - 1, "\n");
+    if(buff && buff_size)
+	memcpy(buff, tmp, buff_size);
+    else
+	fprintf(stderr, tmp);
 }
-#endif
-
-void timer(void){
-    app->timer = g_timeout_add(60000,
+//#endif
+/*******************************************************************************/
+void timer(int interval){
+    app->timer = g_timeout_add(interval,
 			       (GtkFunction)timer_handler,
-			       app->main_window); /* One per minute */
+			       app->main_window);
 }
-
+/*******************************************************************************/
 /* Free memory allocated for time event */
 void free_list_time_event(void){
     static GSList *list_time_event_temp = NULL;
@@ -124,7 +135,7 @@ void free_list_time_event(void){
     
     #ifdef PC_EMULATOR
     fprintf(stderr,"Free ALL in list\n");
-    print_list();
+    print_list(NULL, 0);
     #endif
     if(!event_time_list)
 	return;
@@ -142,11 +153,11 @@ void free_list_time_event(void){
     event_time_list = NULL;
     #ifdef PC_EMULATOR
     fprintf(stderr,"list clean\n");
-    print_list();
+    print_list(NULL, 0);
     #endif
 
 }
-
+/*******************************************************************************/
 /* Compare function for sort event list */
 static gint compare_time(gconstpointer a, gconstpointer b){
     struct event_time *evta, *evtb;
@@ -155,34 +166,40 @@ static gint compare_time(gconstpointer a, gconstpointer b){
     evtb = (struct event_time*)b;
     return(evta->time < evtb->time) ? -1 : (evta->time > evtb->time) ? +1 : 0;
 }
-
+/*******************************************************************************/
 /* Add time event  to list */	  
 void time_event_add(time_t time_value, short type_event){
-    struct event_time *evt;
+    struct event_time *evt = NULL;
 
     #ifdef PC_EMULATOR
-    fprintf(stderr,"time_event_add in list\n");
-    print_list();
+/*     fprintf(stderr,"time_event_add in list\n");
+    print_list(NULL, 0); 
+*/    
     #endif
-    if( time_value && time_value > time(NULL) ){
+    if( time_value && time_value > time(NULL)){ 
 	evt = g_new0(struct event_time, 1);
-	evt->time = time_value;	  
-	evt->type_event = type_event;
-	event_time_list = g_slist_insert_sorted(event_time_list,evt,compare_time);
+	if (evt != NULL) 
+	{
+	    evt->time = time_value;	  
+	    evt->type_event = type_event;
+	    event_time_list = g_slist_insert_sorted(event_time_list,evt,compare_time);
+	}    
+	else
+	    fprintf(stderr,"evt NULL\n");
     }
     #ifdef PC_EMULATOR
-    fprintf(stderr,"time_event_add in list finished\n");
-    print_list();
+/*     fprintf(stderr,"time_event_add in list finished\n");
+     print_list(NULL, 0); 
+*/     
     #endif
-    
 }
-
+/*******************************************************************************/
 /* Add periodic time event  to list */	  
 void add_periodic_event(time_t last_update){
 
     #ifdef PC_EMULATOR
     fprintf(stderr,"Add in list\n");
-    print_list();
+    print_list(NULL, 0);
     #endif
 
     if(app->update_interval > 0)
@@ -190,11 +207,11 @@ void add_periodic_event(time_t last_update){
 
     #ifdef PC_EMULATOR
     fprintf(stderr,"Item added to list\n");
-    print_list();
+    print_list(NULL, 0);
     #endif
 	
 }
-
+/*******************************************************************************/
 /* Remove periodic time event  from list */	  
 void remove_periodic_event(void){
     static GSList *list_time_event_temp = NULL;
@@ -202,23 +219,70 @@ void remove_periodic_event(void){
     
     #ifdef PC_EMULATOR
     fprintf(stderr,"Periodic remove from list\n");
-    print_list();
+    print_list(NULL, 0);
     #endif
 
     if(!event_time_list)
 	return;
-    list_time_event_temp = event_time_list;
+    list_time_event_temp = event_time_list;  
     while(list_time_event_temp != NULL){
 	evt = list_time_event_temp->data;
 	if(evt->type_event == AUTOUPDATE){
+	    event_time_list = g_slist_remove(event_time_list, list_time_event_temp->data);
+	    list_time_event_temp = event_time_list;  
 	    g_free(evt);
-	    list_time_event_temp = g_slist_remove(list_time_event_temp, list_time_event_temp->data);
 	}
 	list_time_event_temp = g_slist_next(list_time_event_temp);
     }
-    event_time_list = list_time_event_temp;
+
     #ifdef PC_EMULATOR
     fprintf(stderr,"Periodic is remove from list\n");
-    print_list();
+    print_list(NULL, 0);
     #endif
 }
+/*******************************************************************************/
+void remove_daytime_event(void){
+    static GSList *list_time_event_temp = NULL;
+    struct event_time *evt;
+    
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"DAYTIMEEVENT remove from list\n");
+    print_list(NULL, 0);
+    #endif
+
+    if(!event_time_list)
+	return;
+    list_time_event_temp = event_time_list;  
+    while(list_time_event_temp != NULL){
+	evt = list_time_event_temp->data;
+	if(evt->type_event == DAYTIMEEVENT){
+	    event_time_list = g_slist_remove(event_time_list, list_time_event_temp->data);
+	    list_time_event_temp = event_time_list;  
+	    g_free(evt);
+	}
+	list_time_event_temp = g_slist_next(list_time_event_temp);
+    }
+
+    #ifdef PC_EMULATOR
+    fprintf(stderr,"DAYTIMEEVENT is remove from list\n");
+    print_list(NULL, 0);
+    #endif
+}
+/*******************************************************************************/
+time_t next_update(void){
+    GSList	*tmp_list = NULL;
+    time_t	result	= 0;
+
+    if(!event_time_list)
+	return result;
+    tmp_list = event_time_list;
+    while(tmp_list){
+	if(((struct event_time*)tmp_list->data)->type_event == AUTOUPDATE){
+	    result = ((struct event_time*)tmp_list->data)->time;
+	    break;
+	}
+	tmp_list = g_slist_next(tmp_list);
+    }
+    return result;
+}
+/*******************************************************************************/
