@@ -30,15 +30,18 @@
 
 #ifndef _weather_event_h
 #define _weather_event_h 1
-
+/*******************************************************************************/
 #include "weather-home_common.h"
-
+/*******************************************************************************/
 gboolean timer_handler(gpointer data);
-void timer(void);
+void timer(int interval);
 void add_periodic_event(time_t last_update);
-void print_list(void);
+void remove_daytime_event(void);
+void remove_periodic_event(void);
+void print_list(char *buff, size_t buff_size);
 void time_event_add(time_t time_value, short type_event);
 extern gboolean not_event;
 extern void weather_initialize_dbus(void);
-
+time_t next_update(void);
+/*******************************************************************************/
 #endif
