@@ -25,13 +25,13 @@
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
-	
 */
-
+/*******************************************************************************/
 #include "weather-home_config.h"
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+/*******************************************************************************/
 /*
  * Change the weather cache directory and update dependent variables.
  */
@@ -49,14 +49,13 @@ gboolean config_set_weather_dir_name(gchar *new_weather_dir_name){
         	parent = gnome_vfs_uri_get_parent(curr_uri), 0755))
             list = g_list_prepend(list, curr_uri = parent);	
 	while(list != NULL){
-    	    retval = (GNOME_VFS_OK == gnome_vfs_make_directory_for_uri(
-                    	(GnomeVFSURI*)list->data, 0755));
-    	    gnome_vfs_uri_unref((GnomeVFSURI*)list->data);
-    	
-    
+	    if( GNOME_VFS_OK != gnome_vfs_make_directory_for_uri((GnomeVFSURI*)list->data, 0755) ){
+		retval = FALSE;
+		break;
+	    }
     	    list = g_list_remove(list, list->data);
     	}
-	retval = FALSE;
+	retval = TRUE;
     }
     else
 	retval = TRUE;
@@ -68,7 +67,7 @@ gboolean config_set_weather_dir_name(gchar *new_weather_dir_name){
     gnome_vfs_uri_unref(weather_dir_uri);
     return retval;
 }
-
+/*******************************************************************************/
 /* Add time update to list */
 void add_time_update_list(gint _between_time, gchar *_time_name){
     struct time_update *tu;
@@ -77,7 +76,58 @@ void add_time_update_list(gint _between_time, gchar *_time_name){
     tu->name_between_time = g_strdup(_time_name);	  
     time_update_list = g_slist_append(time_update_list, tu);
 }
-
+/*******************************************************************************/
+/* The stations data  fill from clock plugin data */
+void fill_station_from_clock_plugin_data(void){
+    FILE  *clock_file;  
+    gchar *home_city = NULL;
+    gchar *remote_city = NULL;
+    gchar *tmp = NULL;
+    char  out_buffer[1024]; /* buffer for work with city_in_clock.txt files*/
+    struct weather_station *ws;
+    
+    GConfClient *gconf_client = gconf_client_get_default();
+    /* City name from config file of clock */
+    home_city = gconf_client_get_string(gconf_client,
+        			    GCONF_KEY_CLOCK_HOME_LOCATION, NULL);  
+    if(!home_city)
+	return;
+    remote_city = gconf_client_get_string(gconf_client,
+        			    GCONF_KEY_CLOCK_REMOTE_LOCATION, NULL);
+    if(!remote_city)
+	return;
+    if((clock_file = fopen(CLOCK_FILE,"r")) != NULL){
+	while(!feof(clock_file)){
+	    memset(out_buffer, 0, sizeof(out_buffer)); /* Clear buffer */
+	    fgets(out_buffer, sizeof(out_buffer), clock_file); /* Read Next Line */
+	    tmp = strchr(out_buffer,'|'); /* Finding of a separator */
+	    if ((strncmp(out_buffer,home_city,tmp-out_buffer)==0) || 
+	        (strncmp(out_buffer,remote_city,tmp-out_buffer)==0))
+	    {
+		/* Prepare struct */
+    		ws = g_new0(struct weather_station, 1);
+		tmp[strlen(tmp)-1] = 0;
+		ws->id_station = g_strdup(tmp+1);
+		tmp[0] = 0;
+		ws->name_station = g_strdup(out_buffer);
+		/* Add station to stations list */
+		stations_view_list = g_slist_append(stations_view_list, ws); 
+		/* A current station */
+		if (strncmp(out_buffer,home_city,tmp-out_buffer)==0)
+		{
+		    app->current_station_id = g_strdup(ws->id_station);
+		    app->current_station_name = g_strdup(ws->name_station);
+		}
+	    }	    
+	}
+	fclose (clock_file);
+    }
+    if (home_city)
+	g_free(home_city);
+    if (remote_city)
+	g_free(remote_city);	
+}
+/*******************************************************************************/
 gboolean fill_station_inform( struct weather_station *ws){
     FILE *stations_file;  
     char state_name[21];
@@ -122,7 +172,7 @@ gboolean fill_station_inform( struct weather_station *ws){
     }
     return FALSE;    
 }
-
+/*******************************************************************************/
 /* Reinitialize stations list */
 void reinitilize_stations_list(gchar *stations_string){
     struct weather_station *ws;
@@ -151,7 +201,7 @@ void reinitilize_stations_list(gchar *stations_string){
     }
     g_free(temp1);       
 }
-
+/*******************************************************************************/
 /* New Reinitialize stations list */
 void reinitilize_stations_list2(GSList *stlist){
     struct weather_station *ws = NULL;
@@ -178,7 +228,7 @@ void reinitilize_stations_list2(GSList *stlist){
 	stlist = g_slist_next(stlist);
     }	    
 }
-
+/*******************************************************************************/
 /* Prepare stations ID list in one string to write config file */
 gchar* prepare_idlist_string(void){
     GString *result_string;
@@ -196,7 +246,7 @@ gchar* prepare_idlist_string(void){
     }      
     return g_string_free(result_string, FALSE);
 }
-
+/*******************************************************************************/
 /* Prepare stations ID list  to write config file */
 GSList* prepare_idlist(void){
     GSList *stlist = NULL;
@@ -213,7 +263,7 @@ GSList* prepare_idlist(void){
     }
     return stlist;
 }
-
+/*******************************************************************************/
 /* Initialize all configuration from GCONF.  This should not be called more
  * than once during execution. */
 void read_config(void){
@@ -224,6 +274,7 @@ void read_config(void){
     GSList	*stlist = NULL;
     GError	*gerror = NULL;
     GdkColor	DEFAULT_FONT_COLOR = {0, 0x0d00, 0x2a00, 0xc000};
+
     
     gconf_client = gconf_client_get_default();
 
@@ -239,27 +290,11 @@ void read_config(void){
     if(!config_set_weather_dir_name(gnome_vfs_expand_initial_tilde(tmp)))
         fprintf(stderr, _("Could not create Weather Cache directory.\n"));
     g_free(tmp);
+    tmp = NULL;
     /* Get Weather Station ID for current station */
     app->current_station_id = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_CURRENT_STATION_ID, NULL);
     
-    /* Depricated, after 0.18 not used */				    
-    if(!app->current_station_id)
-	app->current_station_id = gconf_client_get_string(gconf_client,
-        			    GCONF_KEY_WEATHER_STATION_ID, NULL);
-	
-    /* Get Weather Stations ID  */ /* DEPRICATED !!! */
-    /*
-    tmp = gconf_client_get_string(gconf_client,
-        			    GCONF_KEY_WEATHER_STATION_IDS, NULL);
-    if(tmp){
-	reinitilize_stations_list(tmp);
-	g_free(tmp);
-    }
-    else
-	if(app->current_station_id)
-	    reinitilize_stations_list(app->current_station_id);
-*/	    
     /* Get Weather Stations ID and NAME */
     stlist = gconf_client_get_list(gconf_client,
         			    GCONF_KEY_WEATHER_STATIONS_LIST,
@@ -268,7 +303,7 @@ void read_config(void){
 	reinitilize_stations_list2(stlist);
 	g_slist_free(stlist);
     }
-	/* Get icon set name */ 
+    /* Get icon set name */ 
     app->icon_set = gconf_client_get_string(gconf_client,
 					    GCONF_KEY_WEATHER_ICON_SET,
 					    NULL);
@@ -280,12 +315,14 @@ void read_config(void){
     }
     else
 	close(fd);
+	
     /* Get Weather Icon Size  */		     
     app->icons_size = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_ICONS_SIZE,
 					    NULL);
-    if(app->icons_size < 0)
+    if(app->icons_size < 0 || app->icons_size < LARGE || app->icons_size > SMALL)
         app->icons_size = LARGE;
+	
     /* Get Weather country name. */    
     app->current_country = gconf_client_get_string(gconf_client,
         					    GCONF_KEY_WEATHER_CURRENT_COUNTRY_NAME,
@@ -298,14 +335,15 @@ void read_config(void){
     app->update_interval = gconf_client_get_int(gconf_client,
         			    GCONF_KEY_WEATHER_UPDATE_INTERVAL,
 				    NULL);
-    if(app->update_interval < 0)
+    if(app->update_interval < 0 || app->update_interval > 8)
 	app->update_interval = 0;
     /* Get Weather font color. */    	
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_FONT_COLOR, NULL);
     if(!tmp || !gdk_color_parse(tmp, &(app->font_color)))
-         app->font_color = DEFAULT_FONT_COLOR;
+         app->font_color = DEFAULT_FONT_COLOR; 
     g_free(tmp);
+    tmp = NULL;
     /* Get Enable Transparency flag. Default is TRUE. */
     value = gconf_client_get(gconf_client, GCONF_KEY_ENABLE_TRANSPARENCY, NULL);
     if(value){
@@ -314,7 +352,22 @@ void read_config(void){
     }
     else
         app->transparency = TRUE;      
-	
+    /* Get Split Button State. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_SEPARATE_DATA, NULL);
+    if(value){
+        app->separate = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        app->separate = FALSE;      	
+    /* Get Swap Temperature Button State. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_SWAP_TEMPERATURE, NULL);
+    if(value){
+        app->swap_hi_low_temperature = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        app->swap_hi_low_temperature = FALSE;      	
 	
     /* Get Temperature Unit  Default Celsius */
     app->temperature_units = gconf_client_get_int(gconf_client,
@@ -338,53 +391,48 @@ void read_config(void){
 	g_error_free(gerror);
 	gerror = NULL;
     }
-
-    /* Depricated, after 0.18 not used */
+    /* Get Layout  Default Horizontal */
     app->icons_layout = gconf_client_get_int(gconf_client,
-                			    GCONF_KEY_WEATHER_LAYOUT,
-					    NULL);
-    
-    if(app->icons_layout == 0)
-	    /* Get Layout  Default Horizontal */
-	    app->icons_layout = gconf_client_get_int(gconf_client,
                 			    GCONF_KEY_ICONS_LAYOUT,
 					    NULL);
+    if(app->icons_layout < ONE_ROW || app->icons_layout > TWO_COLUMNS)
+	app->icons_layout = ONE_ROW;
     /* Get number days to show */
     app->days_to_show = gconf_client_get_int(gconf_client,                                                                                     
                 	    GCONF_KEY_WEATHER_DAYS, &gerror);
-    if(gerror || !app->days_to_show){
-	app->days_to_show = 5;
+    if(gerror || app->days_to_show <= 0 || app->days_to_show > Max_count_weather_day){
+	app->days_to_show = 5;/* default value */
 	g_error_free(gerror);
     }
+
     app->previos_days_to_show = app->days_to_show;
     /* Get distance units */
     app->distance_units = gconf_client_get_int(gconf_client,                                                                                     
                 	    GCONF_KEY_WEATHER_DISTANCE_UNITS, &gerror);
-    if(gerror){
+    if(gerror || app->distance_units < METERS || app->distance_units > SEA_MILES){
 	app->distance_units = METERS;
 	g_error_free(gerror);
     }
     /* Get wind units */
     app->wind_units = gconf_client_get_int(gconf_client,                                                                                     
 			GCONF_KEY_WEATHER_WIND_UNITS, &gerror);
-    if(gerror){
+    if(gerror || app->wind_units < METERS_S || app->wind_units > MILES_H){
 	app->wind_units = METERS_S;
 	g_error_free(gerror);
     }
-    /* Fill time update list */
-    if(!time_update_list){
-	add_time_update_list(0, _("Never"));
-	add_time_update_list(5, _("5 minutes"));
-	add_time_update_list(30, _("30 minutes"));
-	add_time_update_list(1 * 60, _("1 hour"));
-	add_time_update_list(2 * 60, _("2 hours"));
-	add_time_update_list(4 * 60, _("4 hours"));
-	add_time_update_list(8 * 60, _("8 hours"));
-	add_time_update_list(24 * 60, _("24 hours"));
-/* #ifdef PC_EMULATOR */
-	add_time_update_list(1, _("1 minute (DEBUG)"));
-/* #endif */
+    /* Get valid data time for current weather */
+    app->data_valid_interval = gconf_client_get_int(gconf_client,                                                                                     
+			GCONF_KEY_WEATHER_VALID_DATA_TIME, &gerror);
+    if(gerror || (app->data_valid_interval != 1 &&
+		    app->data_valid_interval != 2 && 
+		    app->data_valid_interval != 4 &&
+		    app->data_valid_interval != 8) ){
+	app->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
+	g_error_free(gerror);
     }
+    else
+	app->data_valid_interval *= 3600;
+    
     /* Check connection */
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_CURRENT_CONNECTIVITY, NULL);
@@ -395,11 +443,42 @@ void read_config(void){
     else
 	app->iap_connected = FALSE;
 	
+    
+    /* If this first start then fill default station from clock config */ 
+    tmp =gconf_client_get_string(gconf_client,
+                     GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);     
+    if (!tmp){
+	if(!app->current_station_id){
+	    fill_station_from_clock_plugin_data();
+	    if (app->iap_connected){
+		app->show_update_window = TRUE;
+		update_weather();
+	    }	
+	}	    
+    }
+    else{
+	g_free(tmp);		     
+	tmp = NULL;		
+    }
+    /* Fill time update list */
+    if(!time_update_list){
+	add_time_update_list(0, _("Never"));
+	add_time_update_list(5, _("every 5 minutes"));
+	add_time_update_list(30, _("every 30 minutes"));
+	add_time_update_list(1 * 60, _("every hour"));
+	add_time_update_list(2 * 60, _("every 2 hours"));
+	add_time_update_list(4 * 60, _("every 4 hours"));
+	add_time_update_list(8 * 60, _("every 8 hours"));
+	add_time_update_list(24 * 60, _("every 24 hours"));
+/* #ifdef PC_EMULATOR */
+	add_time_update_list(1, _("every minute (DEBUG)"));
+/* #endif */
+    }
     app->show_update_window = FALSE;
     gconf_client_clear_cache(gconf_client);
     g_object_unref(gconf_client);
 }
-
+/*******************************************************************************/
 void config_update_proxy(void){
     GConfClient *gconf_client = gconf_client_get_default();
     if(app->iap_http_proxy_host)
@@ -419,7 +498,7 @@ void config_update_proxy(void){
     }
     g_object_unref(gconf_client);
 }
-
+/*******************************************************************************/
 /* Save current station position configuration data to GCONF. */
 void config_save_current_station(){
     GConfClient *gconf_client = gconf_client_get_default();
@@ -438,11 +517,10 @@ void config_save_current_station(){
             GCONF_KEY_WEATHER_CURRENT_STATION_ID, app->current_station_id, NULL);
     g_object_unref(gconf_client);
 }
- 
+/*******************************************************************************/ 
 /* Save all configuration data to GCONF. */
 void config_save(){
     gchar temp_buffer[16];
-    gchar *idlist_string;
     GConfClient *gconf_client;
     GSList *stlist = NULL;
    
@@ -451,6 +529,11 @@ void config_save(){
 	fprintf(stderr, _("Failed to initialize GConf. Settings were not saved.\n"));
         return;
     }
+    /* Save program version */
+    if(VERSION)
+        gconf_client_set_string(gconf_client,
+        			GCONF_KEY_WEATHER_PROGRAM_VERSION,
+				VERSION, NULL);
     /* Save Weather Cache Directory. */
     if(app->weather_dir_name)
         gconf_client_set_string(gconf_client,
@@ -479,12 +562,6 @@ void config_save(){
         gconf_client_set_string(gconf_client,
         			GCONF_KEY_WEATHER_CURRENT_STATION_ID,
 				"", NULL);
-     /* Temporary in release 0.1 8 deleted */
-    idlist_string = g_strdup("");
-    gconf_client_set_string(gconf_client,
-        		    GCONF_KEY_WEATHER_STATION_IDS,
-			    idlist_string, NULL);
-    g_free(idlist_string);
     /* Save icon set name */
     if(app->icon_set)
 	gconf_client_set_string(gconf_client,
@@ -509,7 +586,15 @@ void config_save(){
      /* Save Enable Enable Transparency flag. */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_ENABLE_TRANSPARENCY,
-			app->transparency, NULL);	    
+			app->transparency, NULL);
+     /* Save Split Button State */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_SEPARATE_DATA,
+			app->separate, NULL);	    
+     /* Save Swap Temperature Button State */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_SWAP_TEMPERATURE,
+			app->swap_hi_low_temperature, NULL);	    
     /* Save Weather Temperature Unit  */		     	    
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_TEMPERATURE_UNIT,
@@ -526,6 +611,10 @@ void config_save(){
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_WIND_UNITS,
 			app->wind_units, NULL);
+    /* Save valid data time */
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_WEATHER_VALID_DATA_TIME,
+			app->data_valid_interval / 3600, NULL);
     /* Save Layout type. */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_ICONS_LAYOUT,
@@ -540,3 +629,4 @@ void config_save(){
     g_slist_free(stlist);
     g_object_unref(gconf_client);
 }
+/*******************************************************************************/
