@@ -25,12 +25,11 @@
  * License along with this software; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA
-	
 */
-
+/*******************************************************************************/
 #include "weather-home_parser.h"
 #include "weather-home_hash.h"
-
+/*******************************************************************************/
 weather_com_parser *weather_parser_new_from_file(const gchar *filename){
     weather_com_parser *parser;
 
@@ -49,8 +48,7 @@ weather_com_parser *weather_parser_new_from_file(const gchar *filename){
     }
     return parser;
 }
-
-
+/*******************************************************************************/
 int parse_weather_com_xml(void){
     weather_com_parser	*parser;
     xmlNode	*cur_node	= NULL,
@@ -146,6 +144,14 @@ int parse_weather_com_xml(void){
 			    xmlFree(temp_xml_string);
 			}    
 		    }	
+		    if( child_node->type == XML_ELEMENT_NODE  && 
+			    ( !xmlStrcmp(child_node->name, (const xmlChar *)"zone") ) ){
+			for (i = 0; i < Max_count_weather_day; i++){
+			    temp_xml_string = xmlNodeGetContent(child_node);
+			    weather_days[i].zone = atol((char*)temp_xml_string) * 60 * 60;
+			    xmlFree(temp_xml_string);
+			}
+		    }	
 		}
 	    }
 	/* Fill current day */
@@ -261,24 +267,25 @@ int parse_weather_com_xml(void){
 			if( count_day < Max_count_weather_day ){ /* Check limit day */
 			    count_day++; 
 			    temp_xml_string = xmlGetProp(child_node, (const xmlChar*)"t");
-			    snprintf(weather_days[count_day-1].dayshname,
-				     sizeof(weather_days[count_day-1].dayshname) - 1,
-				     "%s",
-				    (char*)hash_table_find(get_short_name((char*)temp_xml_string, 0)));
+			    memset(buffer, 0, sizeof(buffer));
+			    memcpy(buffer, temp_xml_string,
+				    (sizeof(buffer) > strlen((char*)temp_xml_string)) ? strlen((char*)temp_xml_string)
+										: sizeof(buffer));
+			    strptime(buffer, "%A", tm);
+			    memset(weather_days[count_day - 1].dayshname, 0,
+				    sizeof(weather_days[count_day - 1].dayshname));
+			    strftime(weather_days[count_day-1].dayshname,
+			            sizeof(weather_days[count_day-1].dayshname) - 1,
+				    "%a", tm);
 			    xmlFree(temp_xml_string);
 			    temp_xml_string = xmlGetProp(child_node, (const xmlChar*)"t");
-			    snprintf(weather_days[count_day-1].dayfuname,
+			    memset(weather_days[count_day - 1].dayfuname, 0,
+				    sizeof(weather_days[count_day - 1].dayfuname));
+			    snprintf(weather_days[count_day - 1].dayfuname,
 				     sizeof(weather_days[count_day-1].dayfuname) - 1, "%s",
-				     (char*)hash_table_find(temp_xml_string));
+				     temp_xml_string);
 			    xmlFree(temp_xml_string);				     
-			    /*
-			    tmp = (char*)xmlGetProp(child_node, (const xmlChar*)"dt");
-			    split_date(tmp, &date);
-			    snprintf(weather_days[count_day-1].date,
-				     sizeof(weather_days[count_day-1].date) - 1,
-				     "%s %d",
-				     (char*)hash_table_find(tmp), date);
-			    */
+
 			    temp_xml_string = xmlGetProp(child_node, (const xmlChar*)"dt");
 			    snprintf(weather_days[count_day-1].date,
         			     sizeof(weather_days[count_day-1].date) - 1,
@@ -360,6 +367,7 @@ int parse_weather_com_xml(void){
 								    temp_xml_string = xmlNodeGetContent(child_node4);	
 								    snprintf(weather_days[count_day-1].day.wind_speed,
 									    sizeof(weather_days[count_day-1].day.wind_speed) - 1,
+									    "%s",
 									    (char*)temp_xml_string);
 								    xmlFree(temp_xml_string);
 								}
@@ -372,7 +380,9 @@ int parse_weather_com_xml(void){
 									     "%s",
 									     (char*)hash_table_find(temp_xml_string));
 								else
-								    sprintf(weather_days[count_day-1].day.wind_title,"%.10s",
+								    snprintf(weather_days[count_day-1].day.wind_title,
+									     sizeof(weather_days[count_day-1].day.wind_title) - 1,
+									    "%s",
 									    (char*)hash_table_find(temp_xml_string));
     								xmlFree(temp_xml_string);
     								
@@ -425,44 +435,4 @@ int parse_weather_com_xml(void){
     free(parser);
     return count_day;     
 }
-
-char* get_short_name(const char* name, gboolean what){
-    char	*result = "N/A";
-
-    switch(what){
-	default:
-	case 0:
-	    ( !strcmp(name, "Monday") ) && (result = "Mo");
-	    ( !strcmp(name, "Thursday") ) && (result = "Th");
-	    ( !strcmp(name, "Tuesday") ) && (result = "Tu");
-	    ( !strcmp(name, "Sunday") ) && (result = "Su");
-	    ( !strcmp(name, "Wednesday") ) && (result = "We");
-	    ( !strcmp(name, "Saturday") ) && (result = "Sa");
-	    ( !strcmp(name, "Friday") ) && (result = "Fr");
-	break;
-	case 1:
-	    ( strstr("January", name) ) && (result = "Jan");
-	    ( strstr("February", name) ) && (result = "Feb");
-	    ( strstr("March", name) ) && (result = "Mar");
-	    ( strstr("April", name) ) && (result = "Apr");
-	    ( strstr("May", name) ) && (result = "May");
-	    ( strstr("June", name) ) && (result = "Jun");
-	    ( strstr("July", name) ) && (result = "Jul");
-	    ( strstr("August", name) ) && (result = "Aug");
-	    ( strstr("September", name) ) && (result = "Sep");
-	    ( strstr("October", name) ) && (result = "Oct");
-	    ( strstr("November", name) ) && (result = "Nov");
-	    ( strstr("December", name) ) && (result = "Dec");
-	break;
-    }
-    return result;
-}
-
-void split_date(char* string, int *day){
-    char *str;
-    
-    if( (str = strchr(string, ' ')) ){ 
-	*str = 0; str++;
-	*day = atoi(str);
-    }
-}
+/*******************************************************************************/
